==> haskell-data-tree-print-0.1.0.2-166-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-8yiSQyWklzl7bmvK7a9meH
key:                  data-tree-print-0.1.0.2-8yiSQyWklzl7bmvK7a9meH
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  5fb77102df26d96d4a161a33d5ab7679
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-tree-print
hs-libraries:         HSdata-tree-print-0.1.0.2-8yiSQyWklzl7bmvK7a9meH
depends:
    base-4.17.2.1 pretty-1.1.3.6 syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-tree-print-0.1.0.2-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-tree-print.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 data-tree-print
version:              0.1.0.2
visibility:           public
id:                   data-tree-print-0.1.0.2-JS1Ufc3Haid2FtI1gwbWmH
key:                  data-tree-print-0.1.0.2-JS1Ufc3Haid2FtI1gwbWmH
license:              BSD-3-Clause
copyright:            Copyright (C) 2016 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
homepage:             https://github.com/lspitzner/data-tree-print
synopsis:             Print Data instances as a nested tree
description:
    Provides functionality similar to that of the `Show` class: Taking some
    arbitrary value and returning a String.

    * Output is not intended to be valid haskell.

    * Requires a `Data.Data.Data` instance instead of a `Text.Show` one.

    * Output, if large, is often easier to parse than `show` output
    due to the formatting as a nested tree.

    * The user can adapt the behaviour at runtime using custom layouting
    expressed via syb-style extension.

category:             Pretty Printer
abi:                  aa51b2828acac87e42f6c18742a53841
exposed:              True
exposed-modules:      DataTreePrint
import-dirs:          /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/data-tree-print-0.1.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-tree-print
hs-libraries:         HSdata-tree-print-0.1.0.2-JS1Ufc3Haid2FtI1gwbWmH
depends:
    base-4.17.2.1 pretty-1.1.3.6 syb-0.7.2.4-LCfC87e8e3VJWZAOynmRLq

haddock-interfaces:
    /usr/share/doc/haskell-data-tree-print/html/data-tree-print.haddock

haddock-html:         /usr/share/doc/haskell-data-tree-print/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
